@@ -1,4 +1,4 @@
-/* $Id: gdict-app.c,v 1.33 2002/02/02 21:32:31 kevinv Exp $ */
+/* $Id: gdict-app.c,v 1.34 2002/02/21 05:17:25 hadess Exp $ */
 /* -*- mode: c; style: k&r; c-basic-offset: 4 -*- */
 
 /*
@@ -464,11 +464,8 @@ void
 gdict_app_show_preferences (void) 
 {
 	
-    if (!pref_dialog) {
-    g_print ("show prefs \n");
+    if (!pref_dialog)
         pref_dialog = gdict_pref_dialog_new (context);
-        
-    }
 
     gtk_widget_show (pref_dialog);
 }
