@@ -1,4 +1,4 @@
-/* $Id: gdict-pref-dialog.c,v 1.19 2002/02/02 21:32:31 kevinv Exp $ */
+/* $Id: gdict-pref-dialog.c,v 1.20 2002/02/21 05:17:25 hadess Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -246,8 +246,9 @@ create_dialog (GDictPrefDialog *pref_dialog)
     g_signal_connect (G_OBJECT (pref_dialog), "response",
     		      G_CALLBACK (response_cb), NULL);
 
-    gtk_entry_set_text (GTK_ENTRY (pref_dialog->server_entry),
-			gdict_pref.server);
+    if (gdict_pref.server != NULL)
+	    gtk_entry_set_text (GTK_ENTRY (pref_dialog->server_entry),
+				gdict_pref.server);
     port_str = g_strdup_printf("%d", (int) gdict_pref.port);
     gtk_entry_set_text (GTK_ENTRY (pref_dialog->port_entry), port_str);
     g_free(port_str);
@@ -348,8 +349,9 @@ pref_dialog_add_db (GDictPrefDialog *pref_dialog, gchar *db,
     gtk_object_set_data (GTK_OBJECT (menu_item), "db_name", db);
     gtk_widget_show (menu_item);
     gtk_menu_append (pref_dialog->db_list, menu_item);
-    
-    if (!strcmp (pref_dialog->database, db))
+
+    if ((pref_dialog->database == NULL)
+		    || (!strcmp (pref_dialog->database, db)))
       gtk_menu_set_active (pref_dialog->db_list, pref_dialog->database_idx);
     pref_dialog->database_idx++;
 }
@@ -372,7 +374,8 @@ pref_dialog_add_strat (GDictPrefDialog *pref_dialog, gchar *strat,
     gtk_widget_show (menu_item);
     gtk_menu_append (pref_dialog->strat_list, menu_item);
     
-    if (!strcmp (pref_dialog->dfl_strat, strat))
+    if ((pref_dialog->dfl_strat == NULL)
+		    || (!strcmp (pref_dialog->dfl_strat, strat)))
 	gtk_menu_set_active (pref_dialog->strat_list,
 			     pref_dialog->dfl_strat_idx);
     pref_dialog->dfl_strat_idx++;
@@ -580,12 +583,14 @@ server_button_cb (GtkButton *button, gpointer data)
     gchar *server;
     server = gtk_editable_get_chars (GTK_EDITABLE (pref_dialog->server_entry), 0, -1);
 
-    if (strcmp (gdict_pref.server, server)) {
+    if ((server != NULL)
+		    && ((gdict_pref.server == NULL)
+			    || (strcmp (gdict_pref.server, server)))) {
 	gchar *old_server;
 	
-        old_server = gdict_pref.server; 
+        old_server = gdict_pref.server;
         gdict_pref.server = g_strdup(server);
-       
+
         /* Try connecting. If we fail, restore the old config and abort */
         if (gdict_init_context ()) {
         	        GtkWidget *dialog;
@@ -601,8 +606,14 @@ server_button_cb (GtkButton *button, gpointer data)
 			g_free (gdict_pref.server);
 			gdict_pref.server = old_server;
 			gdict_init_context ();
-			gtk_entry_set_text (GTK_ENTRY (pref_dialog->server_entry),
-				            gdict_pref.server);
+			if (gdict_pref.server != NULL)
+				gtk_entry_set_text
+					(GTK_ENTRY (pref_dialog->server_entry),
+					            gdict_pref.server);
+			else
+				gtk_entry_set_text
+					(GTK_ENTRY (pref_dialog->server_entry),
+					            "");
 			return;
 		}
 	else {
