@@ -1,4 +1,4 @@
-/* $Id: gdict-speller.c,v 1.9 2001/12/03 01:57:26 kevinv Exp $ */
+/* $Id: gdict-speller.c,v 1.11 2002/02/02 21:32:31 kevinv Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -110,6 +110,8 @@ gdict_speller_get_type (void) {
 static void 
 gdict_speller_init (GDictSpeller *speller) {
     GtkWidget *label, *button, *scrolled_win;
+    GtkWidget *sep;
+    GtkWidget *hbox;
     GtkListStore *model;
     GtkTreeViewColumn *column;
     GtkTreeSelection *selection;
@@ -120,34 +122,56 @@ gdict_speller_init (GDictSpeller *speller) {
     speller->spell_cmd = NULL;
     speller->strat = gdict_pref.dfl_strat;
     
-    speller->table = GTK_TABLE (gtk_table_new (2, 3, FALSE));
-    gtk_table_set_row_spacings (speller->table, 5);
-    gtk_table_set_col_spacings (speller->table, 5);
+    hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
+    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (speller)->vbox), hbox, FALSE, FALSE, 0);
     
-    button = gtk_button_new_with_mnemonic (_("_Spell"));
-    gtk_table_attach_defaults (speller->table, button, 0, 1, 0, 1);
+    label = gtk_label_new (_("Word : "));
+    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+    
+    speller->word_entry = GTK_ENTRY (gtk_entry_new ());
+    gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (speller->word_entry), TRUE, TRUE, 0);
+    g_signal_connect (G_OBJECT (speller->word_entry), "activate",
+    	  	      G_CALLBACK (spell_entry_cb), speller);
+    
+    label = gtk_label_new_with_mnemonic (_("_Spell"));
+    gtk_misc_set_padding (GTK_MISC (label), GNOME_PAD_SMALL, 1);
+    
+    button = gtk_button_new ();
+    gtk_container_add (GTK_CONTAINER (button), label);
+    gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
     g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (spell_button_pressed),
     		      speller);
     
-    speller->word_entry = GTK_ENTRY (gtk_entry_new ());
-    gtk_table_attach_defaults (speller->table, 
-		               GTK_WIDGET (speller->word_entry), 1, 2, 0, 1);
-    g_signal_connect (G_OBJECT (speller->word_entry), "activate",
-    	  	      G_CALLBACK (spell_entry_cb), speller);
+    speller->hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
+    gtk_container_set_border_width (GTK_CONTAINER (speller->hbox), GNOME_PAD);
+    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (speller)->vbox), speller->hbox, 
+    			FALSE, FALSE, 0);
     
     label = gtk_label_new (_("Search Strategy:"));
     gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_RIGHT);
     gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
-    gtk_table_attach_defaults (speller->table, label, 0, 1, 1, 2);
+    gtk_box_pack_start (GTK_BOX (speller->hbox), label, FALSE, FALSE, 0);
+        
+    hbox = gtk_hbox_new (FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (speller)->vbox), hbox, FALSE, 
+    			FALSE, GNOME_PAD_SMALL);
+    
+    hbox = gtk_hbox_new (FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (speller)->vbox), hbox, FALSE, FALSE, 0);
+    
+    label = gtk_label_new (_("Search Results"));
+    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+    
+    sep = gtk_hseparator_new ();
+    gtk_box_pack_start (GTK_BOX (hbox), sep, TRUE, TRUE, GNOME_PAD_SMALL);
     
     scrolled_win = gtk_scrolled_window_new (NULL, NULL);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_win),
                                     GTK_POLICY_NEVER,
                                     GTK_POLICY_AUTOMATIC);
     gtk_widget_set_usize (scrolled_win, 400, 250);
-    
-    gtk_table_attach (speller->table, scrolled_win, 0, 2, 2, 3, 
-                      GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 5);
+    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (speller)->vbox), scrolled_win, 
+    			TRUE, TRUE, GNOME_PAD);
     
     model = gtk_list_store_new (1, G_TYPE_STRING);
     
@@ -166,24 +190,23 @@ gdict_speller_init (GDictSpeller *speller) {
     						       NULL);
     gtk_tree_view_column_set_sort_column_id (column, 0);
     
-    gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (model),
-                                          0,GTK_SORT_ASCENDING); 
+    /*gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (model),
+                                          0,GTK_SORT_ASCENDING); */
                                           
     gtk_tree_view_append_column (GTK_TREE_VIEW (speller->word_list), column);
     gtk_container_add (GTK_CONTAINER (scrolled_win), speller->word_list);
 
     gtk_dialog_add_buttons (GTK_DIALOG (speller), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
-    		                                  _("_Look Up"), 100,
+    		                                  _("_Look Up Word"), 100,
     		                                  NULL);
     g_signal_connect (G_OBJECT (speller->word_list), "row_activated",
-    		      G_CALLBACK (row_activated_cb), speller);	                                  
+    		      G_CALLBACK (row_activated_cb), speller);
+    		      
     g_signal_connect (G_OBJECT (speller), "response", G_CALLBACK (spell_response_cb),
     		      speller);
     gtk_window_set_title (GTK_WINDOW (speller), _("Spell checker"));
-    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (speller)->vbox),
-                        GTK_WIDGET (speller->table), 5, TRUE, TRUE);
-                         
-    gtk_widget_show_all (GTK_WIDGET (speller->table));
+                           
+    gtk_widget_show_all (GTK_WIDGET (GTK_DIALOG (speller)->vbox));
 }
 
 /* gdict_speller_class_init
@@ -389,7 +412,7 @@ gdict_speller_reset_strat (GDictSpeller *speller) {
     if (speller->strat_sel) {
         gtk_option_menu_remove_menu (speller->strat_sel);
         gtk_widget_destroy (GTK_WIDGET (speller->strat_sel));
-        gtk_widget_show_all (GTK_WIDGET (speller->table));
+        gtk_widget_show_all (GTK_WIDGET (speller->hbox));
         speller->strat_sel = NULL;
     }
     
@@ -412,8 +435,8 @@ gdict_speller_reset_strat (GDictSpeller *speller) {
         alignment = gtk_alignment_new (0, 0.5, 0, 0);
         gtk_container_add (GTK_CONTAINER (alignment), 
                            GTK_WIDGET (error_label));
-        gtk_table_attach_defaults (speller->table, alignment, 1, 2, 1, 2);
-        gtk_widget_show_all (GTK_WIDGET (speller->table));
+        gtk_box_pack_start (GTK_BOX (speller->hbox), alignment, TRUE, TRUE, 0);
+        gtk_widget_show_all (GTK_WIDGET (speller->hbox));
     }
 }
 
@@ -432,9 +455,14 @@ spell_error_cb (dict_command_t *command, DictStatusCode code,
     speller = GTK_WINDOW (data);
     
     if (code != DICT_SOCKET_ERROR) {
+        GtkWidget *dialog;
         string = g_strdup_printf (_("Error invoking query: %s"), message);
-        gnome_error_dialog_parented (string, speller);
-        
+        dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
+                                  	 GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
+                                  	 "%s", string, NULL); 
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
+        g_free (string);
         if (command->cmd == C_MATCH)
           gtk_signal_emit (GTK_OBJECT (speller), 
                            gdict_speller_signals[WORD_LOOKUP_DONE_SIGNAL]);
@@ -486,12 +514,17 @@ speller_set_strat_cb (GtkWidget *widget, gpointer data) {
 static void
 speller_add_strat (GDictSpeller *speller, gchar *strat, gchar *desc) {
     GtkWidget *menu_item;
+    GtkWidget *label;
     
-    menu_item = gtk_menu_item_new_with_label (desc);
+    label = gtk_label_new (desc);
+    gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+    
+    menu_item = gtk_menu_item_new ();
     gtk_signal_connect (GTK_OBJECT (menu_item), "activate", 
                         GTK_SIGNAL_FUNC (speller_set_strat_cb), speller);
     gtk_object_set_data (GTK_OBJECT (menu_item), "strat_name", strat);
-    gtk_widget_show (menu_item);
+    gtk_container_add (GTK_CONTAINER (menu_item), label);
+    gtk_widget_show_all (menu_item);
     gtk_menu_append (speller->strat_list, menu_item);
     
     if (!strcmp (speller->strat, strat))
@@ -573,8 +606,8 @@ spell_strat_status_cb (dict_command_t *command, DictStatusCode code,
         alignment = gtk_alignment_new (0, 0.5, 0, 0);
         gtk_container_add (GTK_CONTAINER (alignment), 
                            GTK_WIDGET (speller->strat_sel));
-        gtk_table_attach_defaults (speller->table, alignment, 1, 2, 1, 2);
-        gtk_widget_show_all (GTK_WIDGET (speller->table));
+        gtk_box_pack_start (GTK_BOX (speller->hbox), alignment, TRUE, TRUE, 0);
+        gtk_widget_show_all (GTK_WIDGET (speller->hbox));
     }
 }
 
