@@ -276,14 +276,16 @@ make_find_cmd (const char *start_dir)
 {
 	GString *cmdbuf;
 	GList *list;
+	gchar *escape_dir = NULL;
 	
 	if (criteria_find==NULL) return NULL;
 
 	cmdbuf = g_string_new ("");
 
-	if(start_dir)
-		g_string_append_printf(cmdbuf, "find %s %s ", start_dir, defoptions);
-	else
+	if(start_dir) {
+		escape_dir = g_strescape(start_dir, NULL);
+		g_string_append_printf(cmdbuf, "find \"%s\" %s ", escape_dir, defoptions);
+	} else
 		g_string_append_printf(cmdbuf, "find . %s ", defoptions);
 
 	for(list=criteria_find;list!=NULL;list=g_list_next(list)) {
@@ -322,7 +324,9 @@ make_find_cmd (const char *start_dir)
 			}
 		}
 	}
-	g_string_append (cmdbuf, "-print0 ");
+	g_string_append (cmdbuf, "-print ");
+
+	g_free(escape_dir);
 
 	return g_string_free(cmdbuf, FALSE);
 }
@@ -606,14 +610,14 @@ add_file_to_list_store(const gchar *file, GtkListStore *store, GtkTreeIter *iter
 	readable_size = gnome_vfs_format_file_size_for_display (vfs_file_info->size);
 	readable_date = get_readable_date (vfs_file_info->mtime);
 	date = get_basic_date (vfs_file_info->mtime);
-	
+
 	gtk_list_store_append (GTK_LIST_STORE(store), iter); 
-	gtk_list_store_set (GTK_LIST_STORE(store), iter, 
+	gtk_list_store_set (GTK_LIST_STORE(store), iter,
 			    COLUMN_ICON, pixbuf, 
 			    COLUMN_NAME, get_file_base_name(utf8_file),
 			    COLUMN_PATH, get_file_dir_name(utf8_file),
 			    COLUMN_READABLE_SIZE, readable_size,
-			    COLUMN_SIZE, vfs_file_info->size,
+			    COLUMN_SIZE, (gdouble) vfs_file_info->size,
 			    COLUMN_TYPE, description,
 			    COLUMN_READABLE_DATE, readable_date,
 			    COLUMN_DATE, date,
@@ -666,7 +670,27 @@ really_run_command(char *cmd, char sepchar, RunLevel *running, GtkWidget *tree,
 		close(fd[1]);
 		close(fderr[1]);
 
-		execl("/bin/sh", "/bin/sh", "-c", cmd, NULL);
+		{
+			gchar *shell = NULL;
+
+			shell = g_find_program_in_path ("sh");
+			if (shell == NULL)
+			{
+				GtkWidget *dialog;
+
+				dialog = gtk_message_dialog_new(NULL,
+					0,
+					GTK_MESSAGE_ERROR,
+					GTK_BUTTONS_OK,
+					_("Cannot perform the search.\n"
+					"The Bourne shell was not found\n"
+					"It is typically installed as /bin/sh or /usr/bin/sh."));
+				gtk_dialog_run (GTK_DIALOG (dialog));
+				gtk_widget_destroy (dialog);
+			}
+			execl(shell, shell, "-c", cmd, NULL);
+			g_free(shell);
+		}
 		_exit(0); /* in case it fails */
 	}
 	close(fd[1]);
@@ -813,7 +837,7 @@ run_command(GtkWidget *w, gpointer data)
 		gtk_widget_show(buttons[0]);
 		gtk_widget_hide(buttons[1]);
 
-		really_run_command(cmd, '\0', &find_running, find_tree, find_model, &find_iter);
+		really_run_command(cmd, '\n', &find_running, find_tree, find_model, &find_iter);
 		
 		gtk_widget_set_sensitive(buttons[1], TRUE);
 		gtk_widget_hide(buttons[0]);
@@ -1675,6 +1699,25 @@ save_results(GtkFileSelection *selector, gpointer user_data)
 	
 	filename = (gchar *)gtk_file_selection_get_filename(GTK_FILE_SELECTION(file_selector));
 	
+	if (access (filename, F_OK) == 0) {
+		GtkWidget *dialog;
+		gint response;
+		
+		dialog = gtk_message_dialog_new
+			(GTK_WINDOW (file_selector),
+			 0 /* flags */,
+			 GTK_MESSAGE_QUESTION,
+			 GTK_BUTTONS_YES_NO,
+			 _("File %s already exists. Overwrite?"),
+			 filename);
+			 
+		response = gtk_dialog_run (GTK_DIALOG (dialog));
+		
+		gtk_widget_destroy (GTK_WIDGET(dialog));
+		
+		if (response != GTK_RESPONSE_YES) return;
+	}
+	
 	if (fp = fopen(filename, "w")) {
 	
 		if (gtk_tree_model_get_iter_root(GTK_TREE_MODEL(store), &iter)) {
