@@ -24,6 +24,7 @@
 
 #include <config.h>
 #include <gnome.h>
+#include <gconf/gconf-client.h>
 #include <unistd.h>
 #include <time.h>
 #include <sys/stat.h>
@@ -73,6 +74,7 @@ void print_db (GList *gb);
 Log *OpenLogFile (char *);
 GtkWidget *new_pixmap_from_data (char  **, GdkWindow *, GdkColor *);
 GtkWidget *create_menu (char *item[], int n);
+void SaveUserPrefs(UserPrefsStruct *prefs);
 
 /*
  *    ,-------.
@@ -166,6 +168,8 @@ UserPrefsStruct user_prefs_struct = {0};
 ConfigData *cfg = NULL;
 GtkWidget *open_file_dialog = NULL;
 
+GConfClient *client;
+
 extern GdkGC *gc;
 extern Log *curlog, *loglist[];
 extern int numlogs, curlognum;
@@ -202,6 +206,9 @@ main (int argc, char *argv[])
 
   gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-log.png");
   
+  gconf_init (argc, argv, NULL);
+  client = gconf_client_get_default ();
+  
   /*  Load graphics config */
   cfg = CreateConfig();
   
@@ -215,6 +222,8 @@ main (int argc, char *argv[])
    
   /*  Loop application */
   gtk_main ();
+  
+  SaveUserPrefs(user_prefs);
 
   return 0;
 }
@@ -681,7 +690,8 @@ LoadLogMenu (GtkWidget * widget, gpointer user_data)
    gtk_window_set_modal (GTK_WINDOW (filesel), TRUE);
 
    gtk_file_selection_set_filename (GTK_FILE_SELECTION (filesel), 
-   				    PATH_MESSAGES);
+   				    user_prefs->logfile);
+
    gtk_window_set_position (GTK_WINDOW (filesel), GTK_WIN_POS_MOUSE);
    gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (filesel)->ok_button),
 		       "clicked", (GtkSignalFunc) FileSelectOk,
@@ -727,7 +737,9 @@ CloseApp (void)
    for (i = 0; i < numlogs; i++)
       CloseLog (loglist[i]);
 
-   gtk_exit (0);
+   numlogs = 0;
+
+   gtk_main_quit ();   
 }
 
 /* ----------------------------------------------------------------------
@@ -746,7 +758,7 @@ open_databases (void)
 	found = FALSE;
 	if (cfg->regexp_db_path != NULL) {
 		g_snprintf (full_name, sizeof (full_name),
-			    "%s/logview-regexp.db", cfg->regexp_db_path);
+			    "%s/gnome-system-log-regexp.db", cfg->regexp_db_path);
 		DB (fprintf (stderr, "Looking for database in [%s]\n", cfg->regexp_db_path));
 		if (access (full_name, R_OK) == 0)  {
 			found = TRUE;
@@ -756,7 +768,7 @@ open_databases (void)
 
 	if ( ! found) {
 		g_snprintf (full_name, sizeof (full_name),
-			    "%s/share/logview/logview-regexp.db", LOGVIEWINSTALLPREFIX);
+			    "%s/share/gnome-system-log/gnome-system-log-regexp.db", LOGVIEWINSTALLPREFIX);
 		if (access (full_name, R_OK) == 0) {
 			found = TRUE;
 			g_free (cfg->regexp_db_path);
@@ -769,7 +781,7 @@ open_databases (void)
 	found = FALSE;
 	if (cfg->descript_db_path != NULL) {
 		g_snprintf (full_name, sizeof (full_name),
-			    "%s/logview-descript.db", cfg->descript_db_path);
+			    "%s/gnome-system-log-descript.db", cfg->descript_db_path);
 		DB (fprintf (stderr, "Looking for database in [%s]\n", cfg->descript_db_path));
 		if (access (full_name, R_OK) == 0) {
 			read_descript_db (full_name, &descript_db);
@@ -779,7 +791,7 @@ open_databases (void)
 
 	if ( ! found) {
 		g_snprintf (full_name, sizeof (full_name),
-			    "%s/share/logview/logview-descript.db", LOGVIEWINSTALLPREFIX);
+			    "%s/share/gnome-system-log/gnome-system-log-descript.db", LOGVIEWINSTALLPREFIX);
 		if (access (full_name, R_OK) == 0) {
 			found = TRUE;
 			g_free (cfg->descript_db_path);
@@ -792,7 +804,7 @@ open_databases (void)
 	/* Find action DB ------------------------------------------------  */
 	found = FALSE;
 	g_snprintf (full_name, sizeof (full_name),
-		    "%s/.gnome/logview-actions.db", g_get_home_dir ());
+		    "%s/.gnome/gnome-system-log-actions.db", g_get_home_dir ());
 	DB (fprintf (stderr, "Looking for database in [%s/.gnome]\n",
 		     g_get_home_dir ()));
 	if (access (full_name, R_OK) == 0) {
@@ -802,7 +814,7 @@ open_databases (void)
 
 	if ( ! found && cfg->action_db_path != NULL) {
 		g_snprintf (full_name, sizeof (full_name),
-			    "%s/logview-actions.db", cfg->action_db_path);
+			    "%s/gnome-system-log-actions.db", cfg->action_db_path);
 		DB (fprintf (stderr, "Looking for database in [%s]\n", cfg->action_db_path));
 		if (access (full_name, R_OK) == 0) {
 			found = TRUE;
@@ -813,7 +825,7 @@ open_databases (void)
 
 	if ( ! found) {
 		g_snprintf (full_name, sizeof (full_name),
-			    "%s/share/logview/logview-actions.db", LOGVIEWINSTALLPREFIX);
+			    "%s/share/gnome-system-log/gnome-system-log-actions.db", LOGVIEWINSTALLPREFIX);
 		if (access (full_name, R_OK) == 0) {
 			found = TRUE;
 			g_free (cfg->action_db_path);
@@ -843,8 +855,41 @@ void SetDefaultUserPrefs(UserPrefsStruct *prefs)
 {
 	/* Make defaults configurable later */
 	/* Will have to save prefs. eventually too*/
-
+	gchar *logfile = NULL;
+	struct stat filestat;
+	
+	/* FIXME: load saved values. Should install gconf schemas file for
+	** defaults 
+	*/
 	prefs->process_column_width = 12;
 	prefs->hostname_column_width = 15;
 	prefs->message_column_width = 24;
+	
+	logfile = gconf_client_get_string (client, "/apps/logview/logfile", NULL);
+	if (logfile != NULL) {
+		prefs->logfile = g_strdup (logfile);
+		g_free (logfile);
+	}
+	else {
+		/* First time running logview. Try to find the logfile */
+		if (lstat("/var/adm/messages", &filestat)) 
+			prefs->logfile = g_strdup ("/var/log/messages");
+		else if (lstat("/var/log/messages", &filestat)) 
+			prefs->logfile = g_strdup ("/var/log/messages");
+		else
+			prefs->logfile = NULL;
+	}
+	
+}
+
+void SaveUserPrefs(UserPrefsStruct *prefs)
+{
+    gconf_client_set_string (client, "/apps/logview/logfile", prefs->logfile, NULL);
+    gconf_client_set_int (client, "/apps/logview/process_column_width",
+    			  prefs->process_column_width, NULL);
+    gconf_client_set_int (client, "/apps/logview/hostname_column_width",
+    			  prefs->hostname_column_width, NULL);
+    gconf_client_set_int (client, "/apps/logview/message_column_width",
+    			  prefs->message_column_width, NULL);
+
 }
